Package: operators
Type: Package
Title: Additional Binary Operators
Version: 0.2.0
Authors@R: c(
    person("Romain", "Francois", email = "romain@tada.science", role = c("cre", "aut"))
  )
Depends: R (>= 3.1.0)
Imports: utils
Suggests: testthat
Description: A set of binary operators for common tasks such as regex
        manipulation.
License: MIT + file LICENSE
URL: https://github.com/romainfrancois/operators
BugReports: https://github.com/romainfrancois/operators/issues
RoxygenNote: 7.3.3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-05-04 13:11:59 UTC; romainfrancois
Author: Romain Francois [cre, aut]
Maintainer: Romain Francois <romain@tada.science>
Repository: CRAN
Date/Publication: 2026-05-04 21:10:45 UTC
Built: R 4.5.2; ; 2026-05-04 22:34:02 UTC; unix
