# Generated by roxygen2: do not edit by hand

S3method("%+=%",default)
S3method("%but%",character)
S3method("%but%",default)
S3method("%but%",list)
S3method(print,options)
S3method(print,unixoutput)
S3method(print,withOptions)
S3method(with,options)
export("%!in%")
export("%!~%")
export("%!~*%")
export("%!~+%")
export("%!~|%")
export("%*>%")
export("%*>>%")
export("%+=%")
export("%-~%")
export("%-~|%")
export("%/~%")
export("%2>%")
export("%2>>%")
export("%<%")
export("%<<%")
export("%but%")
export("%file>%")
export("%file>>%")
export("%of%")
export("%o~%")
export("%o~|%")
export("%s~%")
export("%without%")
export("%x=%")
export("%x=|%")
export("%|%")
export("%~%")
export("%~*%")
export("%~+%")
export("%~|%")
importFrom(utils,capture.output)
